Idaho Court of Appeals Civil Opinions | Supreme Court

Skip to main content

# STATE OF IDAHO JUDICIAL BRANCH
Supreme Court Appeals

## Search form

Search

## Court of Appeals Civil Opinions

The Idaho Supreme Court and Idaho Court of Appeals cited opinions are made available online as a public service. All cited opinions are posted the day of their release. West Publishing Company publishes all cited opinions in the Pacific Reporter and Idaho Reports volumes. All cited opinions are removed from this site one-year upon release.

NOTICE: These opinions are subject to formal revision before publication in the preliminary print of the Pacific Reporter. Readers are requested to notify the Clerk of the Court/Reporter of Decisions, Supreme Court of Idaho, Boise, Idaho, 83720-0101, of any typographical or other formal errors, in order that corrections may be made before the preliminary print goes to press.

### By Release Date

- - Release Date | Docket# | Case Name | Opinion | Notes
    Oct 20, 2015 | 43271 | H & W v. John Doe (2015-08) | - Opinion | Termination of parental rights
    Oct 14, 2015 | 42860 | Hausladen v. Sahlin | - Opinion | Appeal from Order to pay fees.
    Sept 30, 2015 | 42798 | Terilyn Gunderson v. Curtis Golden | - Opinion | Petition for equitable division of property in a non-marital relationship.
    July 14, 2015 | 42265 | William Rekow v. Ronald Weekes | - Opinion | Landlord - Tenant
    Apr 21, 2015 | 41684 | Stephen Boswell v. Amber Dawn Steele | - Opinion | Dog bite
    March 30, 2015 | 42040 | Kevin Richard Wernecke v. Idaho Transportation Department | - Opinion | Driver's License Suspension
    March 27, 2015 | 42285 | Caleb Hansen v. Lawerence Denney | - Opinion | Appeal from decision declining to place Hansen on the general election ballot
    March 16, 2015 | 42128 | Charles Lytle v. Julie Lytle | - Opinion | Affirming Denial of motion for relief from judgment
    Jan 14, 2015 | 41216 | Barry Searcy v. State Bd of Corrections | - Opinion | Complaint re fees assessed by correctional institutions
    Dec 16, 2014 | 41733 | Idaho Property Mgmt v. Don Macdonald | - Opinion | Financial liability dispute
    October 31, 2014 | 41483 | Heather Brown v. Michael Brown | - Opinion | Divorce
    Sept 18, 2014 | 41785 | H & W v. Jane Doe (2014-03) | - Opinion | Involuntary hospitalization
    Aug 25, 2014 | 42164 | John Doe v. Jane Doe (2014-12) | - Opinion | Decree terminating parental rights
    Aug 13, 2014 | 40527 | Daniel Chippewa v. State | - Opinion | Post Conviction claim for ineffective assistance of counsel
    July 25, 2014 | 41156 | Hymas v. Meridian Police Deartment | - Opinion | Attorney fees & costs
    May 13, 2014 | 40888 | Mahnami v. Mahnami | - Opinion | Custody
    Apr 24, 2014 | 40642 | Bonner County v. Cunningham | - Opinion | Attorney Fees
    Apr 21, 2014 | 41328 | Rbrt Groves v. State | - Opinion | Sex Offender Registration
    Apr 16, 2014 | 40886 | Barry McHugh v. Jeffrey Reid | - Opinion | Civil Forfeiture
    Apr 1, 2014 | 40866 | Twylla Robinson v. Connie Mueller | - Opinion | Injury
    Feb 21, 2014 | 40808 | Peck v. Idaho Transportation Department | - Opinion |
    Jan 24, 2014 | 40441 | Atwood v. Idaho Transportation Department | - Opinion |
    Sept 10, 2013 | 40149 | Idaho Transportation v. Kalani-Keegan | - Opinion |
    Aug 21, 2013 | 40150 | Wurzburg v. Kootenai County | - Opinion | Valuation of Property
    July 25, 2013 | 39254 | McDavid v. Kiroglu | - Opinion | Appeal From Default Judgement
    July 3, 2013 | 40727 | Re: Jane Doe | - Opinion | Termination of Parental Rights

- Printer-friendly version
- PDF version